@@ -1,10 +1,34 @@
 package App::DBCritic;
 
+# ABSTRACT: Critique a database schema for best practices
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     use App::DBCritic;
+#pod
+#pod     my $critic = App::DBCritic->new(
+#pod         dsn => 'dbi:Oracle:HR', username => 'scott', password => 'tiger');
+#pod     $critic->critique();
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This package is used to scan a database schema and catalog any violations
+#pod of best practices as defined by a set of policy plugins.  It takes conceptual
+#pod and API inspiration from L<Perl::Critic|Perl::Critic>.
+#pod
+#pod B<dbcritic> is the command line interface.
+#pod
+#pod This is a work in progress - please see the L</SUPPORT> section below for
+#pod information on how to contribute.  It especially needs ideas (and
+#pod implementations!) of new policies!
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use Carp;
 use English '-no_match_vars';
 use List::Util 1.33 'any';
@@ -12,12 +36,37 @@ use Module::Pluggable
     search_path => [ __PACKAGE__ . '::Policy' ],
     sub_name    => 'policies',
     instantiate => 'new';
+
+#pod =method policies
+#pod
+#pod Returns an array of loaded policy names that will be applied during
+#pod L</critique>.  By default all modules under the
+#pod C<App::DBCritic::Policy> namespace are loaded.
+#pod
+#pod =cut
+
 use Moo;
 use Scalar::Util 'blessed';
 use App::DBCritic::Loader;
 
 for (qw(username password class_name)) { has $_ => ( is => 'ro' ) }
 
+#pod =attr username
+#pod
+#pod The optional username used to connect to the database.
+#pod
+#pod =attr password
+#pod
+#pod The optional password used to connect to the database.
+#pod
+#pod =attr class_name
+#pod
+#pod The name of a L<DBIx::Class::Schema|DBIx::Class::Schema> class you wish to
+#pod L</critique>.
+#pod Only settable at construction time.
+#pod
+#pod =cut
+
 has dsn => ( is => 'ro', lazy => 1, default => \&_build_dsn );
 
 sub _build_dsn {
@@ -31,6 +80,14 @@ sub _build_dsn {
     return join q{:} => 'dbi', $dbh->{Driver}{Name}, $dbh->{Name};
 }
 
+#pod =attr dsn
+#pod
+#pod The L<DBI|DBI> data source name (required) used to connect to the database.
+#pod If no L</class_name> or L</schema> is provided, L<DBIx::Class::Schema::Loader|DBIx::Class::Schema::Loader> will then
+#pod construct schema classes dynamically to be critiqued.
+#pod
+#pod =cut
+
 has schema => (
     is        => 'ro',
     coerce    => 1,
@@ -69,6 +126,18 @@ sub _coerce_schema {
     croak q{don't know how to make a schema from a } . ref $schema;
 }
 
+#pod =attr schema
+#pod
+#pod A L<DBIx::Class::Schema|DBIx::Class::Schema> object you wish to L</critique>.
+#pod Only settable at construction time.
+#pod
+#pod =attr has_schema
+#pod
+#pod An attribute predicates that is true or false, depending on whether L</schema>
+#pod has been defined.
+#pod
+#pod =cut
+
 has _elements => ( is => 'ro', lazy => 1, default => \&_build__elements );
 
 sub _build__elements {
@@ -86,6 +155,14 @@ sub critique {
     return;
 }
 
+#pod =method critique
+#pod
+#pod Runs the L</schema> through the C<App::DBCritic> engine using all
+#pod the policies that have been loaded and dumps a string representation of
+#pod L</violations> to C<STDOUT>.
+#pod
+#pod =cut
+
 has violations => (
     is      => 'ro',
     lazy    => 1,
@@ -97,6 +174,14 @@ has violations => (
     },
 );
 
+#pod =method violations
+#pod
+#pod Returns an array reference of all
+#pod L<App::DBCritic::Violation|App::DBCritic::Violation>s
+#pod picked up by the various policies.
+#pod
+#pod =cut
+
 sub _policy_loop {
     my ( $self, $policy_type, $elements_ref ) = @_;
     my @violations;
@@ -116,8 +201,6 @@ sub _policy_applies_to {
 
 1;
 
-# ABSTRACT: Critique a database schema for best practices
-
 __END__
 
 =pod
@@ -133,7 +216,7 @@ App::DBCritic - Critique a database schema for best practices
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -157,28 +240,31 @@ implementations!) of new policies!
 
 =head1 ATTRIBUTES
 
+=head2 username
+
+The optional username used to connect to the database.
+
+=head2 password
+
+The optional password used to connect to the database.
+
 =head2 class_name
 
 The name of a L<DBIx::Class::Schema|DBIx::Class::Schema> class you wish to
 L</critique>.
 Only settable at construction time.
 
+=head2 dsn
+
+The L<DBI|DBI> data source name (required) used to connect to the database.
+If no L</class_name> or L</schema> is provided, L<DBIx::Class::Schema::Loader|DBIx::Class::Schema::Loader> will then
+construct schema classes dynamically to be critiqued.
+
 =head2 schema
 
 A L<DBIx::Class::Schema|DBIx::Class::Schema> object you wish to L</critique>.
 Only settable at construction time.
 
-=head2 dsn
-
-=head2 username
-
-=head2 password
-
-The L<DBI|DBI> data source name (required) and optional username and password
-used to connect to the database.  If no L</class_name> or L</schema> is
-provided, L<DBIx::Class::Schema::Loader|DBIx::Class::Schema::Loader> will then
-construct schema classes dynamically to be critiqued.
-
 =head2 has_schema
 
 An attribute predicates that is true or false, depending on whether L</schema>
@@ -241,14 +327,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
