@@ -1,16 +1,53 @@
 package App::DBCritic::Policy;
 
+# ABSTRACT: Role for criticizing database schemas
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     package App::DBCritic::Policy::MyPolicy;
+#pod     use Moo;
+#pod
+#pod     has description => ( default => sub{'Follow my policy'} );
+#pod     has explanation => ( default => {'My way or the highway'} );
+#pod     has applies_to  => ( default => sub { ['ResultSource'] } );
+#pod     with 'App::DBCritic::Policy';
+#pod
+#pod     sub violates { $_[0]->element ne '' }
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a L<role|Moo::Role> consumed by all L<App::DBCritic|App::DBCritic>
+#pod policy plugins.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use English '-no_match_vars';
 use Moo::Role;
 use App::DBCritic::Violation;
 use namespace::autoclean -also => qr{\A _}xms;
 
-requires qw(description explanation violates);
+requires qw(description explanation violates applies_to);
+
+#pod =method description
+#pod
+#pod Required method. Returns a short string describing what's wrong.
+#pod
+#pod =method explanation
+#pod
+#pod Required method. Returns a string giving further details.
+#pod
+#pod =method applies_to
+#pod
+#pod Required method. Returns an array reference of types of
+#pod L<DBIx::Class|DBIx::Class> objects
+#pod indicating what part(s) of the schema the policy is interested in.
+#pod
+#pod =cut
 
 around violates => sub {
     my ( $orig, $self ) = splice @_, 0, 2;
@@ -23,8 +60,36 @@ around violates => sub {
     return;
 };
 
+#pod =method violates
+#pod
+#pod Required method. Role consumers must implement a C<violates> method that
+#pod returns true if the
+#pod policy is violated and false otherwise, based on attributes provided by the
+#pod role.  Callers should call the C<violates> method as the following:
+#pod
+#pod     $policy->violates($element, $schema);
+#pod
+#pod =over
+#pod
+#pod =item Arguments: I<$element>, I<$schema>
+#pod
+#pod =item Return value: nothing if the policy passes, or a
+#pod L<App::DBCritic::Violation|App::DBCritic::Violation>
+#pod object if it doesn't.
+#pod
+#pod =back
+#pod
+#pod =cut
+
 has element => ( is => 'ro', init_arg => undef, writer => '_set_element' );
 
+#pod =attr element
+#pod
+#pod Read-only accessor for the current schema element being examined by
+#pod L<App::DBCritic|App::DBCritic>.
+#pod
+#pod =cut
+
 sub violation {
     my $self = shift;
     return App::DBCritic::Violation->new(
@@ -33,11 +98,24 @@ sub violation {
     );
 }
 
+#pod =method violation
+#pod
+#pod Given a string description of a violation that has been encountered, creates a
+#pod new L<App::DBCritic::Violation|App::DBCritic::Violation>
+#pod object from the current policy.
+#pod
+#pod =cut
+
 has schema => ( is => 'ro', writer => '_set_schema' );
 
-1;
+#pod =attr schema
+#pod
+#pod Read-only accessor for the current schema object being examined by
+#pod L<App::DBCritic|App::DBCritic>.
+#pod
+#pod =cut
 
-# ABSTRACT: Role for criticizing database schemas
+1;
 
 __END__
 
@@ -54,7 +132,7 @@ App::DBCritic::Policy - Role for criticizing database schemas
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -87,12 +165,6 @@ L<App::DBCritic|App::DBCritic>.
 
 =head1 METHODS
 
-=head2 violation
-
-Given a string description of a violation that has been encountered, creates a
-new L<App::DBCritic::Violation|App::DBCritic::Violation>
-object from the current policy.
-
 =head2 description
 
 Required method. Returns a short string describing what's wrong.
@@ -126,6 +198,12 @@ object if it doesn't.
 
 =back
 
+=head2 violation
+
+Given a string description of a violation that has been encountered, creates a
+new L<App::DBCritic::Violation|App::DBCritic::Violation>
+object from the current policy.
+
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -151,14 +229,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
