@@ -1,10 +1,28 @@
 package App::DBCritic::Policy::BidirectionalRelationship;
 
+# ABSTRACT: Check for missing bidirectional relationships in ResultSources
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     use App::DBCritic;
+#pod
+#pod     my $critic = App::DBCritic->new(
+#pod         dsn => 'dbi:Oracle:HR', username => 'scott', password => 'tiger');
+#pod     $critic->critique();
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This policy returns a violation if one or more of a
+#pod L<DBIx::Class::ResultSource|DBIx::Class::ResultSource>'s relationships does not
+#pod have a corresponding reverse relationship in the other class.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use English '-no_match_vars';
 use Moo;
 use Sub::Quote;
@@ -14,12 +32,25 @@ has description => (
     is      => 'ro',
     default => quote_sub q{'Missing bidirectional relationship'},
 );
+
+#pod =attr description
+#pod
+#pod "Missing bidirectional relationship"
+#pod
+#pod =cut
+
 has explanation => (
     is      => 'ro',
     default => quote_sub
         q{'Related tables should have relationships defined in both classes.'},
 );
 
+#pod =attr explanation
+#pod
+#pod "Related tables should have relationships defined in both classes."
+#pod
+#pod =cut
+
 sub violates {
     my $source = shift->element;
 
@@ -29,12 +60,27 @@ sub violates {
         $source->relationships;
 }
 
+#pod =method violates
+#pod
+#pod If the L<"current element"|App::DBCritic::Policy>'s
+#pod L<relationships|DBIx::Class::ResultSource/relationships> do not all have
+#pod corresponding
+#pod L<"reverse relationships"|DBIx::Class::ResultSource/reverse_relationship_info>,
+#pod returns a string describing details of the issue.
+#pod
+#pod =cut
+
 sub _message { return "$_[0] to $_[1] not reciprocated" }
 
 with 'App::DBCritic::PolicyType::ResultSource';
-1;
 
-# ABSTRACT: Check for missing bidirectional relationships in ResultSources
+#pod =attr applies_to
+#pod
+#pod This policy applies to L<ResultSource|DBIx::Class::ResultSource>s.
+#pod
+#pod =cut
+
+1;
 
 __END__
 
@@ -51,7 +97,7 @@ App::DBCritic::Policy::BidirectionalRelationship - Check for missing bidirection
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -116,14 +162,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
