@@ -1,10 +1,28 @@
 package App::DBCritic::Policy::DuplicateRelationships;
 
+# ABSTRACT: Check for ResultSources with unnecessary duplicate relationships
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     use App::DBCritic;
+#pod
+#pod     my $critic = App::DBCritic->new(
+#pod         dsn => 'dbi:Oracle:HR', username => 'scott', password => 'tiger');
+#pod     $critic->critique();
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This policy returns a violation if a
+#pod L<DBIx::Class::ResultSource|DBIx::Class::ResultSource> has relationships to
+#pod other tables that are identical in everything but name.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use Algorithm::Combinatorics 'combinations';
 use Data::Compare;
 use English '-no_match_vars';
@@ -16,12 +34,25 @@ has description => (
     is      => 'ro',
     default => quote_sub q{'Duplicate relationships'},
 );
+
+#pod =attr description
+#pod
+#pod "Duplicate relationships"
+#pod
+#pod =cut
+
 has explanation => (
     is      => 'ro',
     default => quote_sub
         q{'Each connection between tables should only be expressed once.'},
 );
 
+#pod =attr explanation
+#pod
+#pod "Each connection between tables should only be expressed once."
+#pod
+#pod =cut
+
 sub violates {
     my $source = shift->element;
     return if $source->relationships < 2;
@@ -32,10 +63,23 @@ sub violates {
         } combinations( [ $source->relationships ], 2 );
 }
 
-with 'App::DBCritic::PolicyType::ResultSource';
-1;
+#pod =method violates
+#pod
+#pod Returns details if the
+#pod L<"current element"|App::DBCritic::Policy>'s C<relationship_info>
+#pod hashes for any defined relationships are duplicated.
+#pod
+#pod =cut
 
-# ABSTRACT: Check for ResultSources with unnecessary duplicate relationships
+with 'App::DBCritic::PolicyType::ResultSource';
+
+#pod =attr applies_to
+#pod
+#pod This policy applies to L<ResultSource|DBIx::Class::ResultSource>s.
+#pod
+#pod =cut
+
+1;
 
 __END__
 
@@ -52,7 +96,7 @@ App::DBCritic::Policy::DuplicateRelationships - Check for ResultSources with unn
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -115,14 +159,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
