@@ -1,31 +1,74 @@
 package App::DBCritic::Policy::NoPrimaryKey;
 
+# ABSTRACT: Check for DBIx::Class::Schema::ResultSources without primary keys
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     use App::DBCritic;
+#pod
+#pod     my $critic = App::DBCritic->new(
+#pod         dsn => 'dbi:Oracle:HR', username => 'scott', password => 'tiger');
+#pod     $critic->critique();
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This policy returns a violation if a
+#pod L<DBIx::Class::ResultSource|DBIx::Class::ResultSource> has zero primary columns.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use Moo;
 use Sub::Quote;
 use namespace::autoclean -also => qr{\A _}xms;
 
 has description => ( is => 'ro', default => quote_sub q{'No primary key'} );
+
+#pod =attr description
+#pod
+#pod "No primary key"
+#pod
+#pod =cut
+
 has explanation => (
     is      => 'ro',
     default => quote_sub
         q{'Tables should have one or more columns defined as a primary key.'},
 );
 
+#pod =attr explanation
+#pod
+#pod "Tables should have one or more columns defined as a primary key."
+#pod
+#pod =cut
+
 sub violates {
     my $source = shift->element;
     return $source->name . ' has no primary key' if !$source->primary_columns;
     return;
 }
 
-with 'App::DBCritic::PolicyType::ResultSource';
-1;
+#pod =method violates
+#pod
+#pod Returns details if the
+#pod L<"current element"|App::DBCritic::Policy>'s C<primary_columns>
+#pod method returns nothing.
+#pod
+#pod =cut
 
-# ABSTRACT: Check for DBIx::Class::Schema::ResultSources without primary keys
+with 'App::DBCritic::PolicyType::ResultSource';
+
+#pod =attr applies_to
+#pod
+#pod This policy applies to L<ResultSource|DBIx::Class::ResultSource>s.
+#pod
+#pod =cut
+
+1;
 
 __END__
 
@@ -42,7 +85,7 @@ App::DBCritic::Policy::NoPrimaryKey - Check for DBIx::Class::Schema::ResultSourc
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -69,6 +112,8 @@ L<DBIx::Class::ResultSource|DBIx::Class::ResultSource> has zero primary columns.
 
 =head2 applies_to
 
+This policy applies to L<ResultSource|DBIx::Class::ResultSource>s.
+
 =head1 METHODS
 
 =head2 violates
@@ -102,14 +147,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
