@@ -1,10 +1,28 @@
 package App::DBCritic::Policy::NullableTextColumn;
 
+# ABSTRACT: Check for ResultSources with nullable text columns
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     use App::DBCritic;
+#pod
+#pod     my $critic = App::DBCritic->new(
+#pod         dsn => 'dbi:Oracle:HR', username => 'scott', password => 'tiger');
+#pod     $critic->critique();
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This policy returns a violation if a
+#pod L<DBIx::Class::ResultSource|DBIx::Class::ResultSource> has nullable text
+#pod columns.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use DBI ':sql_types';
 use English '-no_match_vars';
 use List::Util 1.33 'any';
@@ -16,12 +34,25 @@ has description => (
     is      => 'ro',
     default => quote_sub q{'Nullable text column'},
 );
+
+#pod =attr description
+#pod
+#pod "Nullable text column"
+#pod
+#pod =cut
+
 has explanation => (
     is      => 'ro',
     default => quote_sub
         q{'Text columns should not be nullable. Default to empty string instead.'},
 );
 
+#pod =attr explanation
+#pod
+#pod "Text columns should not be nullable. Default to empty string instead."
+#pod
+#pod =cut
+
 sub violates {
     my $source = shift->element;
 
@@ -45,10 +76,62 @@ sub violates {
     } keys %column;
 }
 
-with 'App::DBCritic::PolicyType::ResultSource';
-1;
+#pod =method violates
+#pod
+#pod Returns details of each column from the
+#pod L<"current element"|App::DBCritic::Policy> that maps to
+#pod following data types and
+#pod L<"is nullable"|DBIx::Class::ResultSource/is_nullable>:
+#pod
+#pod =over
+#pod
+#pod =item C<TEXT>
+#pod
+#pod =item C<NTEXT>
+#pod
+#pod =item C<CLOB>
+#pod
+#pod =item C<NCLOB>
+#pod
+#pod =item C<CHARACTER>
+#pod
+#pod =item C<CHAR>
+#pod
+#pod =item C<NCHAR>
+#pod
+#pod =item C<VARCHAR>
+#pod
+#pod =item C<VARCHAR2>
+#pod
+#pod =item C<NVARCHAR2>
+#pod
+#pod =item C<CHARACTER VARYING>
+#pod
+#pod =item C<SQL_CHAR>
+#pod
+#pod =item C<SQL_CLOB>
+#pod
+#pod =item C<SQL_VARCHAR>
+#pod
+#pod =item C<SQL_WVARCHAR>
+#pod
+#pod =item C<SQL_LONGVARCHAR>
+#pod
+#pod =item C<SQL_WLONGVARCHAR>
+#pod
+#pod =back
+#pod
+#pod =cut
 
-# ABSTRACT: Check for ResultSources with nullable text columns
+with 'App::DBCritic::PolicyType::ResultSource';
+
+#pod =attr applies_to
+#pod
+#pod This policy applies to L<ResultSource|DBIx::Class::ResultSource>s.
+#pod
+#pod =cut
+
+1;
 
 __END__
 
@@ -65,7 +148,7 @@ App::DBCritic::Policy::NullableTextColumn - Check for ResultSources with nullabl
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -167,14 +250,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
