@@ -1,10 +1,26 @@
 package App::DBCritic::PolicyType;
 
+# ABSTRACT: Role for types of database criticism policies
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     package App::DBCritic::PolicyType::ResultClass;
+#pod     use Moo;
+#pod     with 'App::DBCritic::PolicyType';
+#pod     1;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a L<role|Moo::Role> consumed by all L<App::DBCritic|App::DBCritic>
+#pod policy types.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 require Devel::Symdump;
 use List::MoreUtils;
 use Moo::Role;
@@ -23,9 +39,14 @@ has applies_to => (
 END_SUB
 );
 
-1;
+#pod =attr applies_to
+#pod
+#pod Returns an array reference containing the last component of all the
+#pod C<App::DBCritic::PolicyType> roles composed into the consuming class.
+#pod
+#pod =cut
 
-# ABSTRACT: Role for types of database criticism policies
+1;
 
 __END__
 
@@ -42,7 +63,7 @@ App::DBCritic::PolicyType - Role for types of database criticism policies
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -88,14 +109,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
