@@ -1,17 +1,37 @@
 package App::DBCritic::PolicyType::ResultSource;
 
+# ABSTRACT: Role for ResultSource critic policies
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     package App::DBCritic::Policy::MyResultSourcePolicy;
+#pod     use Moo;
+#pod
+#pod     has description => ( default => sub{'Follow my policy'} );
+#pod     has explanation => ( default => {'My way or the highway'} );
+#pod     sub violates { $_[0]->element ne '' }
+#pod
+#pod     with 'App::DBCritic::PolicyType::ResultSource';
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a role composed into L<App::DBCritic|App::DBCritic> policy classes
+#pod that are interested in L<ResultSource|DBIx::Class::ResultSource>s.  It takes
+#pod care of composing the L<App::DBCritic::Policy|App::DBCritic::Policy>
+#pod for you.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use Moo::Role;
 use namespace::autoclean -also => qr{\A _}xms;
 with 'App::DBCritic::PolicyType';
 1;
 
-# ABSTRACT: Role for ResultSource critic policies
-
 __END__
 
 =pod
@@ -27,7 +47,7 @@ App::DBCritic::PolicyType::ResultSource - Role for ResultSource critic policies
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -72,14 +92,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
