@@ -1,10 +1,30 @@
 package App::DBCritic::Violation;
 
+# ABSTRACT: A violation of a App::DBCritic::Policy
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     use App::DBCritic::Violation;
+#pod
+#pod     my $violation = App::DBCritic::Violation->new(
+#pod         description => 'Violated policy',
+#pod         explanation => 'Consult the rulebook',
+#pod         description => 'The frob table is improperly swizzled.',
+#pod     );
+#pod     print "$violation\n";
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This class represents L<App::DBCritic::Policy|App::DBCritic::Policy>
+#pod violations flagged by L<App::DBCritic|App::DBCritic>.
+#pod
+#pod =cut
+
 use strict;
 use utf8;
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.022';     # VERSION
+our $VERSION = '0.023';     # VERSION
 use Const::Fast;
 use English '-no_match_vars';
 use Moo;
@@ -16,7 +36,33 @@ for (@TEXT_FIELDS) {
     has $_ => ( is => 'ro', default => quote_sub q{q{}} );
 }
 
-has element   => ( is => 'ro' );
+#pod =attr description
+#pod
+#pod A short string briefly describing what's wrong.
+#pod Only settable at construction.
+#pod
+#pod =attr explanation
+#pod
+#pod A string giving a longer general description of the problem.
+#pod Only settable at construction.
+#pod
+#pod =attr details
+#pod
+#pod A string describing the issue as it specifically applies to the L</element>
+#pod being critiqued.
+#pod
+#pod =cut
+
+has element => ( is => 'ro' );
+
+#pod =attr element
+#pod
+#pod The schema element that violated a
+#pod L<App::DBCritic::Policy|App::DBCritic::Policy>.
+#pod Only settable at construction.
+#pod
+#pod =cut
+
 has as_string => ( is => 'ro', lazy => 1, default => \&_build_as_string );
 
 sub _build_as_string {
@@ -34,9 +80,14 @@ sub _build_as_string {
         map { $self->$_ } @TEXT_FIELDS;
 }
 
-1;
+#pod =attr as_string
+#pod
+#pod Returns a string representation of the object.  The same method is called if
+#pod the object appears in double quotes.
+#pod
+#pod =cut
 
-# ABSTRACT: A violation of a App::DBCritic::Policy
+1;
 
 __END__
 
@@ -53,7 +104,7 @@ App::DBCritic::Violation - A violation of a App::DBCritic::Policy
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -124,14 +175,6 @@ L<http://search.cpan.org/dist/App-DBCritic>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-DBCritic>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
